@@ -25,7 +25,7 @@
 #endif
 
 #ifdef HAVE_APPINDICATOR
-#   include <libappindicator/app-indicator.h>
+#   include <libayatana-appindicator/app-indicator.h>
 #endif
 
 #include <gtk/gtk.h>
@@ -36,14 +36,6 @@
 
 typedef enum {SYSTRAY, APPINDICATOR} statusicon_type;
 
-GtkWidget       *lb_mouse_popup;
-GtkWidget       *rb_mouse_popup;
-#ifdef HAVE_APPINDICATOR
-AppIndicator    *appindicator;
-#endif
-GtkStatusIcon   *trayicon;
-statusicon_type icon_type;
-
 void            statusicon_new                      ( void );
 
 void            gtk_status_icon_clicked             ( GtkStatusIcon *status_icon,
